@@ -2,12 +2,20 @@ package vcs
 
 import (
 	"os"
+	"runtime"
+	"strings"
 )
 
 // DetectVcsFromFS detects the type from the local path.
 // Is there a better way to do this?
 func DetectVcsFromFS(vcsPath string) (Type, error) {
 
+	// There are cases under windows that a path could start with a / and it needs
+	// to be stripped. For example, a path such as /C:\foio\bar.
+	if runtime.GOOS == "windows" && strings.HasPrefix(vcsPath, "/") {
+		vcsPath = strings.TrimPrefix(vcsPath, "/")
+	}
+
 	// When the local directory to the package doesn't exist
 	// it's not yet downloaded so we can't detect the type
 	// locally.
